<br/>
<div align="center">
    <img src="assets/logo.svg" height="150px" />
</div>

# Konbini
An intelligent analytics store, open 24/7. Konbini unifies different data management frameworks to power fast and accurate analytic workloads at any scale.

# Documentation
Awaiting soft opening.

# Installation
The package can be installed from PyPi with the following command:
```
pip install konbini
```

# Contributions
We always welcome contributions! Please read our [guide](https://github.com/hyperplane-data/konbini/CONTRIBUTING.md) to get started.
